<?php
/*
 * (c) Kiva Corp.
 */

namespace Plugin\Proteger\Controller;

use Plugin\Proteger\Repository\ProtegerRepository;
use Plugin\Proteger\Service\ProtegerApiService;
use Eccube\Controller\AbstractController;
use Eccube\Repository\ProductRepository;
use Eccube\Repository\ProductClassRepository;
use Eccube\Service\CartService;
use Eccube\Service\PurchaseFlow\PurchaseContext;
use Eccube\Service\PurchaseFlow\PurchaseFlow;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;

/**
 * Class CartAddProtegerController
 * @package Plugin\Proteger\Controller
 */
class CartAddProtegerController extends AbstractController
{
    /**
     * @var PurchaseFlow
     */
    protected $purchaseFlow;

    /**
     * @var CartService
     */
    protected $cartService;

    /**
     * @var ProductRepository
     */
    protected $productRepository;

    /**
     * @var ProductClassRepository
     */
    protected $productClassRepository;

    /**
     * @var ProtegerRepository
     */
    protected $protegerRepository;

    /**
     * @var ProtegerApiService
     */ 
    protected $protegerApiService;

    /**
     * CartAddProtegerController constructor.
     *
     * @param PurchaseFlow $cartPurchaseFlow
     * @param CartService $cartService
     * @param ProductRepository $productRepository
     * @param ProductClassRepository $productClassRepository
     * @param ProtegerRepository $protegerRepository
     * @param ProtegerApiService $protegerApiService
     */
    public function __construct(
        PurchaseFlow $cartPurchaseFlow,
        CartService $cartService,
	ProductRepository $productRepository,
	ProductClassRepository $productClassRepository,
	ProtegerRepository $protegerRepository,
	ProtegerApiService $protegerApiService
    ) {
        $this->purchaseFlow = $cartPurchaseFlow;
        $this->cartService = $cartService;
	$this->productRepository = $productRepository;
	$this->productClassRepository = $productClassRepository;
        $this->protegerRepository = $protegerRepository;
	$this->protegerApiService = $protegerApiService;
    }

    /**
     * @Route("/cart/add-proteger", name="cart-add-proteger")
     * @param Request $request
     *
     * @return Response
     */
    public function index(Request $request)
    {
        switch ($request->getMethod()) {
	    case Request::METHOD_POST:
                return $this->addProteger($request);

            default:
        }
        throw new BadRequestHttpException();
    }

    /**
     * @param Request $request
     *
     * @return JsonResponse
     */
    protected function addProteger(Request $request)
    {
	$data = json_decode($request->getContent(), true);

	$proteger = $this->protegerRepository->findOneBy([], ['id' => 'desc']);
	if (!$proteger) {
	    throw new NotFoundException('The proteger does not exist');
	}

	$accessToken = $proteger->getAccessToken();
        
	$response = $this->protegerApiService->getPlan($data['planId'], $accessToken, $proteger->isProductionEnabled());

	$plan = json_decode($response, true);
	$termLength = $plan['plan']['termLength'];

	$planProductClass = $this->productClassRepository->findOneBy(['code' => 'proteger-'.$termLength]);
	if (!$planProductClass) {
	    return new NotFoundException('The product class does not exist');
	}

	// 保証に紐づく商品の情報をセット
        $productClass = $this->productClassRepository->find($data['parentProductClassId']);
        $planProductClass->setProtegerParentProductName($productClass->getProduct()->getName());
	$planProductClass->setProtegerParentProductClassId($productClass->getId());
	$planProductClass->setProtegerPlanId($plan['plan']['id']);

	// 保証商品の値段をセット
	$planProductClass->setPrice02IncTax($plan['plan']['price']);

	// カートへ追加
	$this->cartService->addProduct($planProductClass, $data['quantity']);

        // 明細の正規化
        $Carts = $this->cartService->getCarts();
        foreach ($Carts as $Cart) {
            $result = $this->purchaseFlow->validate($Cart, new PurchaseContext($Cart, $this->getUser()));
            foreach ($result->getWarning() as $warning) {
                $errorMessages[] = $warning->getMessage();
            }
        }

	$this->cartService->save();

	return new JsonResponse(['status' => 'ok']);
    }
}
