<?php
/*
 * (c) Kiva Corp.
 */

namespace Plugin\Proteger\Controller;

use Eccube\Repository\Master\OrderStatusRepository;
use Eccube\Repository\OrderRepository;
use Eccube\Repository\ShippingRepository;
use Eccube\Service\OrderStateMachine;
use Plugin\Proteger\Dao\OrderDao;
use Plugin\Proteger\E2V\OrderE2V;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\Routing\Annotation\Route;

/**
 * Class OrdersController
 * @package Plugin\Proteger\Controller
 */
class OrdersController extends AbstractController
{
    /**
     * @var OrderDao
     */
    protected $orderDao;

    /**
     * @var OrderRepository
     */
    protected $orderRepository;

    /**
     * @var ShippingRepository
     */
    protected $shippingRepository;

    /**
     * @var OrderStatusRepository
     */
    protected $orderStatusRepository;

    /**
     * OrdersController constructor.
     *
     * @param OrderDao $orderDao
     * @param OrderRepository $orderRepository
     * @param ShippingRepository $shippingRepository
     * @param OrderStatusRepository $orderStatusRepository
     */
    public function __construct(
        OrderDao $orderDao,
        OrderRepository $orderRepository,
        ShippingRepository $shippingRepository,
        OrderStatusRepository $orderStatusRepository
    ) {
        $this->orderDao = $orderDao;
        $this->orderRepository = $orderRepository;
        $this->shippingRepository = $shippingRepository;
        $this->orderStatusRepository = $orderStatusRepository;
    }

    /**
     * @Route("/proteger/orders", name="proteger-orders")
     * @param Request $request
     *
     * @return Response
     */
    public function index(Request $request)
    {
        return parent::index($request);
    }

    /**
     * @param Request $request
     *
     * @return JsonResponse
     * @throws BadRequestHttpException
     */
    protected function process(Request $request)
    {
        switch ($request->getMethod()) {
            case Request::METHOD_GET:
                return $this->onGet($request);

            default:
        }
        throw new BadRequestHttpException();
    }

    /**
     * @param Request $request
     *
     * @return JsonResponse
     */
    protected function onGet(Request $request)
    {
        return $this->createResponse(OrderE2V::convert($this->orderDao->getOrders($request)));
    }
}
