<?php
/*
 * (c) Kiva Corp.
 */

namespace Plugin\Proteger\EventListener;

use Plugin\Proteger\Repository\ProtegerRepository;
use Plugin\Proteger\Service\ProtegerApiService;
use Eccube\Entity\Order;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Workflow\Event\Event;

class OrderEventListener implements EventSubscriberInterface
{
    /**
     * @var ProtegerRepository
     */
    protected $protegerRepository;

    /**
     * @var ProtegerApiService
     */ 
    protected $protegerApiService;

    /**
     * ProductEventListener constructor.
     *
     * @param ProtegerRepository $protegerRepository
     * @param ProtegerApiService $protegerApiService
     */
    public function __construct(
	ProtegerRepository $protegerRepository,
	ProtegerApiService $protegerApiService
    ) {
        $this->protegerRepository = $protegerRepository;
	$this->protegerApiService = $protegerApiService;
    }

    public static function getSubscribedEvents()
    {
        return [
	    'workflow.order.transition.pay' => 'orderPaid',
	    'workflow.order.transition.cancel' => 'orderCancel',
	];
    }

    public function orderPaid(Event $event)
    {
        $Order = $event->getSubject()->getOrder();

	$proteger = $this->protegerRepository->findOneBy([], ['id' => 'DESC']);
	$accessToken = $proteger->getAccessToken();

	$orderId = [
	    'orderId' => $Order->getId(),
	];
	$requestBody = json_encode($orderId);

	$this->protegerApiService->createContract($accessToken, $requestBody, $proteger->isProductionEnabled());
    }

    public function orderCancel(Event $event)
    {
        $Order = $event->getSubject()->getOrder();

	$proteger = $this->protegerRepository->findOneBy([], ['id' => 'DESC']);
	$accessToken = $proteger->getAccessToken();

	$orderId = [
	    'orderId' => $Order->getId(),
	];
	$requestBody = json_encode($orderId);

	$this->protegerApiService->refundContract($accessToken, $requestBody, $proteger->isProductionEnabled());
    }
}
