<?php
/*
 * (c) Kiva Corp.
 */

namespace Plugin\Proteger\EventListener;

use Plugin\Proteger\Repository\ProtegerRepository;
use Plugin\Proteger\Service\ProtegerApiService;
use Eccube\Entity\Product;
use Eccube\Event\EccubeEvents;
use Eccube\Event\EventArgs;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class ProductEventListener implements EventSubscriberInterface
{
    /**
     * @var ProtegerRepository
     */
    protected $protegerRepository;

    /**
     * @var ProtegerApiService
     */ 
    protected $protegerApiService;

    /**
     * ProductEventListener constructor.
     *
     * @param ProtegerRepository $protegerRepository
     * @param ProtegerApiService $protegerApiService
     */
    public function __construct(
	ProtegerRepository $protegerRepository,
	ProtegerApiService $protegerApiService
    ) {
        $this->protegerRepository = $protegerRepository;
	$this->protegerApiService = $protegerApiService;
    }

    public static function getSubscribedEvents()
    {
        return [
	    EccubeEvents::ADMIN_PRODUCT_EDIT_COMPLETE => 'productEdit',
	];
    }

    public function productEdit(EventArgs $event)
    {
        $Product = $event->getArgument("Product");

	$proteger = $this->protegerRepository->findOneBy([], ['id' => 'DESC']);
	$accessToken = $proteger->getAccessToken();

	$productId = [
	    'productId' => $Product->getId(),
	];
	$requestBody = json_encode($productId);

	$this->protegerApiService->Product($accessToken, $requestBody, $proteger->isProductionEnabled());
    }
}
